pub struct CommonConfig {
pub main: MainSettings,
pub loudnorm: LoudnormSettings,
pub export_preset: HashMap<String, ExportConfig>,
}Fields
main: MainSettingsloudnorm: LoudnormSettingsexport_preset: HashMap<String, ExportConfig>Trait Implementations
Sourceimpl Config for CommonConfig
impl Config for CommonConfig
Sourceconst CONFIG_FILE_NAME: &'static str = "common"
const CONFIG_FILE_NAME: &'static str = "common"
The name of the config file, excluding its extension
Sourcefn config_dir() -> PathBuf
fn config_dir() -> PathBuf
The config dir the file is stored in Read more
fn __config_dir() -> &'static Path
Sourcefn load() -> Result<Self, ConfigError>
fn load() -> Result<Self, ConfigError>
Loads
Self from the system config directory using Self::CONFIG_FILE_NAME, creating a default config if one does not already existfn from_toml(toml: impl AsRef<str>) -> Result<Self, ConfigError>
fn print_default() -> String
Sourceimpl Debug for CommonConfig
impl Debug for CommonConfig
Sourceimpl Default for CommonConfig
impl Default for CommonConfig
Sourcefn default() -> CommonConfig
fn default() -> CommonConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CommonConfigwhere
CommonConfig: Default,
impl<'de> Deserialize<'de> for CommonConfigwhere
CommonConfig: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more