pub enum ContainerFormat {
Flac,
Mp3,
Ogg,
Wav,
}Expand description
All recognized audio containers
Variants
Implementations
Sourceimpl ContainerFormat
impl ContainerFormat
Sourcepub fn format_name(&self) -> &str
pub fn format_name(&self) -> &str
Returns the name as of the container that ffmpeg uses for encoding (the “format_name”)
Sourcepub fn is_supported(&self) -> bool
pub fn is_supported(&self) -> bool
Returns true if the container is contained in SUPPORTED_CONTAINERS
Sourcepub fn from_file(path: impl AsRef<Path>) -> Option<Self>
pub fn from_file(path: impl AsRef<Path>) -> Option<Self>
Wrapper around container_from_file()
For more info, see container_from_file()