Module database

Module database 

Modules

validator
writer

Structs

CompareAndSwapTransaction
CompareAndSwapValue
TreeCompareAndSwap

Enums

DatabaseError

Traits

Createable
DatabaseEntry
Deleteable
EntryId
GenericCompareAndSwap
Mergeable
Patchable
Logic defining how self can be patched by T

Functions

apply_cas_tx
Applies a CompareAndSwapTransaction atomically to the database
db_flush
db_transaction
Calls a closure that returns a CompareAndSwapTransaction and applies it atomically to the database
drop_db
Attempts to delete the entire contents of the database
library_db
Open the library database

Type Aliases

Result