drop_db

Function drop_db 

pub fn drop_db() -> Result<()>
Attempts to delete the entire contents of the database

This function deletes all contents of the database by replacing the existing database entry with None, then deleting the database directory. This will create a new database the next time it is accessed This function should only be used if you know that there are no functions currently trying to read, write, are holding references to the database, like a Tree