FeatureId

Struct FeatureId 

pub struct FeatureId(/* private fields */);
Stable ISO GQL feature identifier.

The private field makes the set closed to this module while preserving the spec’s string IDs as the stable ABI-facing representation.

Implementations

Source

impl FeatureId

pub const fn as_str(self) -> &'static str

Return the ISO feature ID string, such as GP04.

Source

impl FeatureId

pub const G002: FeatureId

Different-edges match mode

pub const G003: FeatureId

Explicit REPEATABLE ELEMENTS keyword

pub const G010: FeatureId

Explicit WALK keyword

pub const G011: FeatureId

Advanced path modes: TRAIL

pub const G012: FeatureId

Advanced path modes: SIMPLE

pub const G013: FeatureId

Advanced path modes: ACYCLIC

pub const G014: FeatureId

Explicit PATH/PATHS keywords

pub const G015: FeatureId

All path search: explicit ALL keyword

pub const G016: FeatureId

Any path search

pub const G017: FeatureId

All shortest path search

pub const G018: FeatureId

Any shortest path search

pub const G019: FeatureId

Counted shortest path search

pub const G020: FeatureId

Counted shortest group search

pub const G036: FeatureId

Quantified edges

pub const G037: FeatureId

Questioned paths

pub const G060: FeatureId

Bounded graph pattern quantifiers

pub const G061: FeatureId

Unbounded graph pattern quantifiers

pub const G100: FeatureId

ELEMENT_ID function

pub const G110: FeatureId

IS DIRECTED predicate

pub const G111: FeatureId

IS LABELED predicate

pub const G112: FeatureId

IS SOURCE and IS DESTINATION predicate

pub const G113: FeatureId

ALL_DIFFERENT predicate

pub const G114: FeatureId

SAME predicate

pub const G115: FeatureId

PROPERTY_EXISTS predicate

pub const GA01: FeatureId

IEEE 754 floating point operations

pub const GA07: FeatureId

Ordering by discarded binding variables

pub const GC02: FeatureId

Graph schema management: IF [ NOT ] EXISTS

pub const GC03: FeatureId

Graph type: IF [ NOT ] EXISTS

pub const GC04: FeatureId

Graph management

pub const GC05: FeatureId

Graph management: IF [ NOT ] EXISTS

pub const GD01: FeatureId

Updatable graphs

pub const GE04: FeatureId

Graph parameters

pub const GE05: FeatureId

Binding table parameters

pub const GE06: FeatureId

Path value construction

pub const GE07: FeatureId

Boolean XOR

pub const GE08: FeatureId

Reference parameters

pub const GA05: FeatureId

Cast specification

pub const GA06: FeatureId

Value type predicate

pub const GF01: FeatureId

Enhanced numeric functions

pub const GF02: FeatureId

Trigonometric functions

pub const GF03: FeatureId

Logarithmic functions

pub const GF04: FeatureId

Enhanced path functions

pub const GF05: FeatureId

Multi-character TRIM function

pub const GF06: FeatureId

Explicit TRIM function

pub const GF07: FeatureId

Byte string TRIM function

pub const GF10: FeatureId

Advanced aggregate functions: general set functions

pub const GF11: FeatureId

Advanced aggregate functions: binary set functions

pub const GF12: FeatureId

CARDINALITY function

pub const GF13: FeatureId

SIZE function

pub const GF20: FeatureId

Aggregate functions in sort keys

pub const GL01: FeatureId

Hexadecimal literals

pub const GL02: FeatureId

Octal literals

pub const GL03: FeatureId

Binary literals

pub const GL04: FeatureId

Exact number in common notation without suffix

pub const GL05: FeatureId

Exact number in common notation or as decimal integer with suffix

pub const GL06: FeatureId

Exact number in scientific notation with suffix

pub const GL07: FeatureId

Approximate number in common notation or as decimal integer with suffix

pub const GL08: FeatureId

Approximate number in scientific notation with suffix

pub const GL09: FeatureId

Optional float number suffix

pub const GL10: FeatureId

Optional double number suffix

pub const GL11: FeatureId

Opt-out character escaping

pub const IM_UUID: FeatureId

selene-db UUID extension

pub const IM_JSON: FeatureId

selene-db JSON extension

pub const IM_VECTOR: FeatureId

selene-db VECTOR extension

pub const IM_EXTENDS: FeatureId

selene-db EXTENDS type composition extension

pub const IM_INDEX_DDL: FeatureId

selene-db named index DDL extension

pub const IM_TYPED_PARAMS: FeatureId

selene-db inline typed parameter declaration extension

pub const IM_TRUNCATE: FeatureId

selene-db bulk truncate extension

pub const IM_DROP_CASCADE: FeatureId

selene-db cascading DROP TYPE extension

pub const IM_DROP_GRAPH: FeatureId

selene-db DROP GRAPH factory-reset extension

pub const GH02: FeatureId

Undirected edge patterns

pub const GG01: FeatureId

Graph with an open graph type

pub const GG02: FeatureId

Graph with a closed graph type

pub const GG20: FeatureId

Explicit element type names

pub const GG21: FeatureId

Explicit element type key label sets

pub const GP01: FeatureId

Inline procedure

pub const GP02: FeatureId

Inline procedure with implicit nested variable scope

pub const GP03: FeatureId

Inline procedure with explicit nested variable scope

pub const GP04: FeatureId

Named procedure calls

pub const GP05: FeatureId

Procedure-local value variable definitions

pub const GP06: FeatureId

Procedure-local value variable definitions: value variables based on simple expressions

pub const GP07: FeatureId

Procedure-local value variable definitions: value variable based on subqueries

pub const GP08: FeatureId

Procedure-local binding table variable definitions

pub const GP09: FeatureId

Procedure-local binding table variable definitions: binding table variables based on simple expressions or references

pub const GP10: FeatureId

Procedure-local binding table variable definitions: binding table variables based on subqueries

pub const GP11: FeatureId

Procedure-local graph variable definitions

pub const GP12: FeatureId

Procedure-local graph variable definitions: graph variables based on simple expressions or references

pub const GP13: FeatureId

Procedure-local graph variable definitions: graph variables based on subqueries

pub const GP14: FeatureId

Binding tables as procedure arguments

pub const GP15: FeatureId

Graphs as procedure arguments

pub const GP18: FeatureId

Catalog and data statement mixing

pub const GQ02: FeatureId

Composite query: OTHERWISE

pub const GQ03: FeatureId

Composite query: UNION

pub const GQ04: FeatureId

Composite query: EXCEPT DISTINCT

pub const GQ05: FeatureId

Composite query: EXCEPT ALL

pub const GQ06: FeatureId

Composite query: INTERSECT DISTINCT

pub const GQ07: FeatureId

Composite query: INTERSECT ALL

pub const GQ08: FeatureId

FILTER statement

pub const GQ09: FeatureId

LET statement

pub const GQ10: FeatureId

FOR statement: list value support

pub const GQ11: FeatureId

FOR statement: WITH ORDINALITY

pub const GQ12: FeatureId

ORDER BY and page statement: OFFSET clause

pub const GQ13: FeatureId

ORDER BY and page statement: LIMIT clause

pub const GQ14: FeatureId

Complex expressions in sort keys

pub const GQ15: FeatureId

GROUP BY clause

pub const GQ16: FeatureId

Pre-projection aliases in sort keys

pub const GQ18: FeatureId

Scalar subqueries

pub const GQ20: FeatureId

Advanced linear composition with NEXT

pub const GQ24: FeatureId

FOR statement: WITH OFFSET

pub const GS01: FeatureId

SESSION SET command: session-local graph parameters

pub const GS02: FeatureId

SESSION SET command: session-local binding table parameters

pub const GS03: FeatureId

SESSION SET command: session-local value parameters

pub const GS04: FeatureId

SESSION RESET command: reset all characteristics

pub const GS05: FeatureId

SESSION RESET command: reset session schema

pub const GS06: FeatureId

SESSION RESET command: reset session graph

pub const GS07: FeatureId

SESSION RESET command: reset time zone displacement

pub const GS08: FeatureId

SESSION RESET command: reset all session parameters

pub const GS10: FeatureId

SESSION SET command: session-local binding table parameters based on subqueries

pub const GS11: FeatureId

SESSION SET command: session-local value parameters based on subqueries

pub const GS12: FeatureId

SESSION SET command: session-local graph parameters based on simple expressions or references

pub const GS13: FeatureId

SESSION SET command: session-local binding table parameters based on simple expressions or references

pub const GS14: FeatureId

SESSION SET command: session-local value parameters based on simple expressions

pub const GS15: FeatureId

SESSION SET command: set time zone displacement

pub const GS16: FeatureId

SESSION RESET command: reset individual session parameters

pub const GT01: FeatureId

Explicit transaction commands

pub const GT03: FeatureId

Use of multiple graphs in a transaction

pub const GV01: FeatureId

8 bit unsigned integer numbers

pub const GV02: FeatureId

8 bit signed integer numbers

pub const GV03: FeatureId

16 bit unsigned integer numbers

pub const GV04: FeatureId

16 bit signed integer numbers

pub const GV05: FeatureId

Small unsigned integer numbers

pub const GV06: FeatureId

32 bit unsigned integer numbers

pub const GV07: FeatureId

32 bit signed integer numbers

pub const GV08: FeatureId

Regular unsigned integer numbers

pub const GV09: FeatureId

Specified integer number precision

pub const GV10: FeatureId

Big unsigned integer numbers

pub const GV11: FeatureId

64 bit unsigned integer numbers

pub const GV12: FeatureId

64 bit signed integer numbers

pub const GV13: FeatureId

128 bit unsigned integer numbers

pub const GV14: FeatureId

128 bit signed integer numbers

pub const GV15: FeatureId

256 bit unsigned integer numbers

pub const GV16: FeatureId

256 bit signed integer numbers

pub const GV17: FeatureId

Decimal numbers

pub const GV18: FeatureId

Small signed integer numbers

pub const GV19: FeatureId

Big signed integer numbers

pub const GV20: FeatureId

16 bit floating point numbers

pub const GV21: FeatureId

32 bit floating point numbers

pub const GV22: FeatureId

Specified floating point number precision

pub const GV23: FeatureId

Floating point type name synonyms

pub const GV24: FeatureId

64 bit floating point numbers

pub const GV25: FeatureId

128 bit floating point numbers

pub const GV26: FeatureId

256 bit floating point numbers

pub const GV30: FeatureId

Specified character string minimum length

pub const GV31: FeatureId

Specified character string maximum length

pub const GV32: FeatureId

Specified character string fixed length

pub const GV35: FeatureId

Byte string types

pub const GV36: FeatureId

Specified byte string minimum length

pub const GV37: FeatureId

Specified byte string maximum length

pub const GV38: FeatureId

Specified byte string fixed length

pub const GV39: FeatureId

Temporal types: date, local datetime and local time support

pub const GV40: FeatureId

Temporal types: zoned datetime and zoned time support

pub const GV41: FeatureId

Temporal types: duration support

pub const GV45: FeatureId

Record types

pub const GV46: FeatureId

Closed record types

pub const GV47: FeatureId

Open record types

pub const GV48: FeatureId

Nested record types

pub const GV50: FeatureId

List value types

pub const GV55: FeatureId

Path value types

pub const GV60: FeatureId

Graph reference value types

pub const GV61: FeatureId

Binding table reference value types

pub const GV66: FeatureId

Open dynamic union types

pub const GV67: FeatureId

Closed dynamic union types

pub const GV68: FeatureId

Dynamic property value types

pub const GV90: FeatureId

Explicit value type nullability