pub struct LabelSet(/* private fields */);Expand description
Sorted set of graph labels.
Implementations
Sourceimpl LabelSet
impl LabelSet
Sourcepub fn from_iter(labels: impl IntoIterator<Item = DbString>) -> Self
pub fn from_iter(labels: impl IntoIterator<Item = DbString>) -> Self
Construct a label set from an iterator, sorting and deduplicating.
Sourcepub fn insert(&mut self, label: DbString) -> bool
pub fn insert(&mut self, label: DbString) -> bool
Insert a label, returning true when it was not already present.