pub struct CollectionId { /* private fields */ }Methods from Deref<Target = Hash>
Sourcepub fn as_bytes(&self) -> &[u8; 32]
pub fn as_bytes(&self) -> &[u8; 32]
The raw bytes of the Hash. Note that byte arrays don’t provide
constant-time equality checking, so if you need to compare hashes,
prefer the Hash type.
Sourcepub fn as_slice(&self) -> &[u8] ⓘ
pub fn as_slice(&self) -> &[u8] ⓘ
The raw bytes of the Hash, as a slice. Useful for serialization. Note that byte arrays
don’t provide constant-time equality checking, so if you need to compare hashes, prefer
the Hash type.
Sourcepub fn to_hex(&self) -> ArrayString<blake3::::{impl#0}::to_hex::{constant#0}>
pub fn to_hex(&self) -> ArrayString<blake3::::{impl#0}::to_hex::{constant#0}>
Encode a Hash in lowercase hexadecimal.
The returned ArrayString is a fixed size and doesn’t allocate memory
on the heap. Note that ArrayString doesn’t provide constant-time
equality checking, so if you need to compare hashes, prefer the Hash
type.