ContainerFormat

Enum ContainerFormat 

pub enum ContainerFormat {
    Flac,
    Mpa,
    Ogg,
    Wav,
    Aiff,
    Ape,
}
All recognized audio containers

Variants



Flac



Mpa



Ogg



Wav



Aiff



Ape

Implementations

Source

impl ContainerFormat

pub fn from_file(handle: &mut File) -> Option<Self>

Gets container type by reading magic bytes

Returns none if the container type is unsupported or unrecognized, or cannot be read

pub fn format_name(&self) -> &str

Returns the name as of the container that ffmpeg uses for encoding (the “format_name”)