pub struct CommonConfig {
pub loudnorm_config: LoudnormConfig,
pub track_name_config: TrackNameConfig,
/* private fields */
}Fields
loudnorm_config: LoudnormConfigtrack_name_config: TrackNameConfigImplementations
Sourceimpl CommonConfig
impl CommonConfig
Sourcepub fn get_source_files(&self) -> Vec<PathBuf>
pub fn get_source_files(&self) -> Vec<PathBuf>
Returns all supported audio files from the configured source directories
Sourceimpl CommonConfig
impl CommonConfig
Sourcepub fn set_library_directory(
&mut self,
path: impl Into<PathBuf>,
) -> Result<&mut Self>
pub fn set_library_directory( &mut self, path: impl Into<PathBuf>, ) -> Result<&mut Self>
Sets your library directory to the input path after validation
The directory is invalid if:
- The library directory starts with a source
- Any source starts with the library directory
- The library directory is equal to any source
- The path is relative
Errors
Errors when sources or the library fail to canonicalize via std::path::Path::canonicalize()
Paths that do not exist on the file system are not canonicalized
Sourcepub fn set_library_sources(&mut self, paths: &[PathBuf]) -> Result<&mut Self>
pub fn set_library_sources(&mut self, paths: &[PathBuf]) -> Result<&mut Self>
Sets your sources to the input sources after validation
Sources are invalid if:
- The library directory starts with the source
- The source starts with the library directory
- The library directory and source are equal
- The source is a relative path
Errors
Errors when sources or the library fail to canonicalize via std::path::Path::canonicalize()
Paths that do not exist on the file system are not canonicalized
Sourceimpl CommonConfig
impl CommonConfig