CasTxLibraryExtensions

Trait CasTxLibraryExtensions 

pub trait CasTxLibraryExtensions {
    // Required methods
    fn album_set_and_relink_tracks(
        &mut self,
        album_id: AlbumId,
        tracks: &[TrackId],
    ) -> Result<bool, TransactionError>;
    fn album_set_and_relink_artists(
        &mut self,
        album_id: AlbumId,
        artists: &[ArtistId],
    ) -> Result<bool, TransactionError>;
    fn relink_track_to_album(
        &mut self,
        track_id: TrackId,
        album: Option<AlbumId>,
    ) -> Result<bool, TransactionError>;
}

Required Methods

Implementations on Foreign Types

Source

impl CasTxLibraryExtensions for CompareAndSwapTransaction<LibraryDb>

Applies a two-way relinking operation, relinking to the track to a new (or no) album, and disconnecting the tracks old album, if any

Applies a two-way relinking operation, relinking artists to the album, and disconnecting references from removed artists

Applies a two-way relinking operation, relinking tracks to the album, and disconnecting references from removed tracks

Implementors