pub struct FeatureId(/* private fields */);Expand description
Stable ISO GQL feature identifier.
The private field makes the set closed to this module while preserving the spec’s string IDs as the stable ABI-facing representation.
Implementations
Sourceimpl FeatureId
impl FeatureId
Sourcepub const GL07: FeatureId
pub const GL07: FeatureId
Approximate number in common notation or as decimal integer with suffix
Sourcepub const IM_EXTENDS: FeatureId
pub const IM_EXTENDS: FeatureId
selene-db EXTENDS type composition extension
Sourcepub const IM_INDEX_DDL: FeatureId
pub const IM_INDEX_DDL: FeatureId
selene-db named index DDL extension
Sourcepub const IM_TYPED_PARAMS: FeatureId
pub const IM_TYPED_PARAMS: FeatureId
selene-db inline typed parameter declaration extension
Sourcepub const IM_TRUNCATE: FeatureId
pub const IM_TRUNCATE: FeatureId
selene-db bulk truncate extension
Sourcepub const IM_DROP_CASCADE: FeatureId
pub const IM_DROP_CASCADE: FeatureId
selene-db cascading DROP TYPE extension
Sourcepub const IM_DROP_GRAPH: FeatureId
pub const IM_DROP_GRAPH: FeatureId
selene-db DROP GRAPH factory-reset extension
Sourcepub const GP06: FeatureId
pub const GP06: FeatureId
Procedure-local value variable definitions: value variables based on simple expressions
Sourcepub const GP07: FeatureId
pub const GP07: FeatureId
Procedure-local value variable definitions: value variable based on subqueries
Sourcepub const GP09: FeatureId
pub const GP09: FeatureId
Procedure-local binding table variable definitions: binding table variables based on simple expressions or references
Sourcepub const GP10: FeatureId
pub const GP10: FeatureId
Procedure-local binding table variable definitions: binding table variables based on subqueries
Sourcepub const GP12: FeatureId
pub const GP12: FeatureId
Procedure-local graph variable definitions: graph variables based on simple expressions or references
Sourcepub const GP13: FeatureId
pub const GP13: FeatureId
Procedure-local graph variable definitions: graph variables based on subqueries
Sourcepub const GS10: FeatureId
pub const GS10: FeatureId
SESSION SET command: session-local binding table parameters based on subqueries
Sourcepub const GS11: FeatureId
pub const GS11: FeatureId
SESSION SET command: session-local value parameters based on subqueries
Sourcepub const GS12: FeatureId
pub const GS12: FeatureId
SESSION SET command: session-local graph parameters based on simple expressions or references
Sourcepub const GS13: FeatureId
pub const GS13: FeatureId
SESSION SET command: session-local binding table parameters based on simple expressions or references