pub enum ContainerFormat {
Flac,
Mpa,
Ogg,
Wav,
Aiff,
Ape,
}Expand description
All recognized audio containers
Variants
Implementations
Sourceimpl ContainerFormat
impl ContainerFormat
Sourcepub fn from_file(handle: &mut File) -> Option<Self>
pub fn from_file(handle: &mut File) -> Option<Self>
Gets container type by reading magic bytes
Returns none if the container type is unsupported or unrecognized, or cannot be read
Sourcepub fn format_name(&self) -> &str
pub fn format_name(&self) -> &str
Returns the name as of the container that ffmpeg uses for encoding (the “format_name”)